@@ -70,7 +70,6 @@ class Vport(object):
         self._create_capture()
         self._set_location()
         self._set_layer1()
-        self._connect()
 
     def _import(self, imports):
         if len(imports) > 0:
@@ -188,26 +187,67 @@ class Vport(object):
             time.sleep(2)
 
     def _set_location(self):
+        # try:
+        #     force_ownership = self._api.config.options.port_options.location_preemption
+        # except:
+        #     force_ownership = False
+        # port_map = self._api.assistant.PortMapAssistant()
+        # vports = self._api.select_vports()
+        # for port in self._api.config.ports:
+        #     if vports[port.name]['connectionState'].startswith('connectedLink'):
+        #         continue
+        #     if len(vports[port.name]['assignedTo']) > 0:
+        #         continue
+        #     if port.location is None or len(port.location) == 0:
+        #         continue
+        #     port_map.Map(Location=port.location, Name=port.name)
+        # if len(port_map._map) > 0:
+        #     port_map.Connect(ForceOwnership=force_ownership,
+        #                     HostReadyTimeout=20,
+        #                     LinkUpTimeout=90)
+        location_supported = True
+        try:
+            self._api._ixnetwork._connection._options(self._api._ixnetwork.href + '/locations')
+        except:
+            location_supported = False
+
         locations = []
         self._add_hosts(10)
         vports = self._api.select_vports()
         imports = []
+        clear_locations = []
         for port in self._api.config.ports:
             vport = vports[port.name]
             location = getattr(port, 'location', None)
-            if vport['location'] == location and vport[
-                    'connectionState'].startswith('connectedLink'):
-                continue
+            if location_supported is True:
+                if vport['location'] == location and vport[
+                        'connectionState'].startswith('connectedLink'):
+                    continue
+            else:
+                if len(vport['connectedTo']) > 0 and vport[
+                        'connectionState'].startswith('connectedLink'):
+                    continue
             self._api.ixn_objects[port.name] = vport['href']
-            vport = {'xpath': vports[port.name]['xpath'], 'location': location}
+            vport = {'xpath': vports[port.name]['xpath']}
+            if location_supported is True:
+                vport['location'] = location
+            else:
+                if location is not None:
+                    xpath = self._api.select_chassis_card_port(location)
+                    vport['connectedTo'] = xpath
+                else:
+                    vport['connectedTo'] = ''
             imports.append(vport)
             if location is not None and len(location) > 0:
+                clear_locations.append(location)
                 locations.append(port.name)
+        self._clear_ownership(clear_locations)
         self._api._ixnetwork.info('Connecting locations [%s]...' %
                                   ', '.join(locations))
         self._import(imports)
         self._api._ixnetwork.info('Checking location state [%s]...' %
                                   ', '.join(locations))
+        self._api._vport.find(ConnectionState='^(?!connectedLink).*$').ConnectPorts()
         start = time.time()
         timeout = 30
         while True:
@@ -251,7 +291,9 @@ class Vport(object):
     def _set_l1config_properties(self, vport, layer1, imports):
         """Set vport l1config properties
         """
-        if vport['connectionState'] not in ['connectedLinkUp', 'connectedLinkDown']:
+        if vport['connectionState'] not in [
+                'connectedLinkUp', 'connectedLinkDown'
+        ]:
             return
         self._set_vport_type(vport, layer1, imports)
         self._set_card_resource_mode(vport, layer1, imports)
@@ -266,7 +308,8 @@ class Vport(object):
             'speed_25_gbps': 'twentyfivegig',
             'speed_40_gbps': 'fortygig',
             'speed_50_gbps': 'fiftygig',
-            'speed_100_gbps': '^(?!.*(twohundredgig|fourhundredgig)).*hundredgig.*$',
+            'speed_100_gbps':
+            '^(?!.*(twohundredgig|fourhundredgig)).*hundredgig.*$',
             'speed_200_gbps': 'twohundredgig',
             'speed_400_gbps': 'fourhundredgig'
         }
@@ -278,13 +321,12 @@ class Vport(object):
                 if re.match(mode, available_mode.lower()) is not None:
                     aggregation_mode = available_mode
                     break
-        if aggregation_mode is not None and aggregation_mode != card['aggregationMode']:
-            imports.append(
-                {
-                    'xpath': card['xpath'], 
-                    'aggregationMode': aggregation_mode            
-                }
-            )
+        if aggregation_mode is not None and aggregation_mode != card[
+                'aggregationMode']:
+            imports.append({
+                'xpath': card['xpath'],
+                'aggregationMode': aggregation_mode
+            })
 
     def _set_auto_negotiation(self, vport, layer1, imports):
         if layer1.speed.endswith('_mbps') or layer1.speed == 'speed_1_gbps':
@@ -302,8 +344,7 @@ class Vport(object):
         be switched to a type without the Fcoe extension.
         """
         fcoe = False
-        if hasattr(layer1,
-                   'flow_control') and layer1.flow_control is not None:
+        if hasattr(layer1, 'flow_control') and layer1.flow_control is not None:
             fcoe = True
         vport_type = vport['type']
         elegible_fcoe_vport_types = [
@@ -349,7 +390,7 @@ class Vport(object):
             advertise
         }
         self._add_l1config_import(vport, proposed_import, imports)
-    
+
     def _add_l1config_import(self, vport, proposed_import, imports):
         type = vport['type'].replace('Fcoe', '')
         l1config = vport['l1Config'][type]
@@ -378,7 +419,8 @@ class Vport(object):
         self._add_l1config_import(vport, proposed_import, imports)
 
     def _reset_auto_negotiation(self, vport, layer1, imports):
-        if layer1.speed.endswith('_mbps') is False and layer1.speed != 'speed_1_gbps':
+        if layer1.speed.endswith(
+                '_mbps') is False and layer1.speed != 'speed_1_gbps':
             imports.append({
                 'xpath':
                 vport['xpath'] + '/l1Config/' +
@@ -416,16 +458,21 @@ class Vport(object):
             }
             imports.append(fcoe)
 
-    def _connect(self):
-        self._ixn_vport.find(ConnectionState='^((?!connectedLink).)*$')
+    def _clear_ownership(self, locations):
         try:
             force_ownership = self._api.config.options.port_options.location_preemption
         except:
             force_ownership = False
-        try:
-            self._ixn_vport.ConnectPorts(force_ownership)
-        except Exception as e:
-            self._api.add_error(e)
+        if force_ownership is True:
+            hrefs = {}
+            chassis = self._api._ixnetwork.AvailableHardware.Chassis
+            for location in locations:
+                clp = location.split(';')
+                chassis.find(Hostname=clp[0])
+                if len(chassis) == 1:
+                    hrefs[location] = '%s/card/%s/port/%s' % (
+                        chassis.href, abs(int(clp[1])), abs(int(clp[2])))
+            self._api.clear_ownership(hrefs)
 
     def _set_result_value(self,
                           row,
